@@ -342,13 +342,13 @@ class PointCloud:
     See `PCL docs <http://pointclouds.org/documentation/tutorials/pcd_file_format.php>`__
     for more information.
     """
-
+    vis = PointCloudVisualizer()
     def __init__(self, metadata, pc_data):
         self.metadata_keys = metadata.keys()
         self.__dict__.update(metadata)
         self.pc_data = pc_data
         self.check_sanity()
-        self.vis = PointCloudVisualizer()
+        
 
     def get_metadata(self):
         """returns copy of metadata"""
@@ -384,7 +384,7 @@ class PointCloud:
             self.vis.img_save(draw, save_path)
         return draw
 
-    def draw_pcloud_fast(
+    def draw_pcloud(
         self,
         color="gray",
         r=0,
@@ -392,16 +392,13 @@ class PointCloud:
         save=False,
         save_path=None,
         draw_distance_marker=True,
+        draw_orin_marker=True,
+        auto_rot=True,
     ):
-        draw = self.vis.draw_pcloud_fast(self.to_ndarray(), color, r, draw_distance_marker)
-        if show:
-            self.vis.img_show(draw)
-        if save:
-            self.vis.img_save(draw, save_path)
+        draw = self.vis.draw_pcloud(self.to_ndarray(['x','y']), color, r, draw_distance_marker, draw_orin_marker,show,auto_rot,save,save_path)
+
         return draw
 
-
-
     def to_ndarray(self, fields=None):
         if not fields:
             fields = self.fields
